@@ -15,7 +15,8 @@ convex.hull<-function(tri.obj,plot.it=F, add=F,...)
                  nt=as.integer(0)
                  )
   ret<-list(x=tri.obj$x[ans$tborder[ans$tborder>0]],
-            y=tri.obj$y[ans$tborder[ans$tborder>0]])
+            y=tri.obj$y[ans$tborder[ans$tborder>0]],
+            i=seq(1,tri.obj$n)[ans$tborder[ans$tborder>0]])
   if(plot.it)
     {
       if (!add)
